==> zio-aws-ec2_2.13-5.17.116.1-sources.jar: zio/aws/ec2/model/FpgaImageState.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class FpgaImageState(
    code: Option[zio.aws.ec2.model.FpgaImageStateCode] = None,
    message: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.FpgaImageState = {
    import FpgaImageState.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.FpgaImageState
      .builder()
      .optionallyWith(code.map(value => value.unwrap))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.FpgaImageState.ReadOnly =
    zio.aws.ec2.model.FpgaImageState.wrap(buildAwsValue())
}
object FpgaImageState {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.FpgaImageState
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.FpgaImageState = zio.aws.ec2.model
      .FpgaImageState(code.map(value => value), message.map(value => value))
    def code: Option[zio.aws.ec2.model.FpgaImageStateCode]
    def message: Option[String]
    def getCode: ZIO[Any, AwsError, zio.aws.ec2.model.FpgaImageStateCode] =
      AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.FpgaImageState
  ) extends zio.aws.ec2.model.FpgaImageState.ReadOnly {
    override val code: Option[zio.aws.ec2.model.FpgaImageStateCode] = scala
      .Option(impl.code())
      .map(value => zio.aws.ec2.model.FpgaImageStateCode.wrap(value))
    override val message: Option[String] =
      scala.Option(impl.message()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.FpgaImageState
  ): zio.aws.ec2.model.FpgaImageState.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.267.1-sources.jar: zio/aws/ec2/model/FpgaImageState.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class FpgaImageState(
    code: Optional[zio.aws.ec2.model.FpgaImageStateCode] = Optional.Absent,
    message: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.FpgaImageState = {
    import FpgaImageState.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.FpgaImageState
      .builder()
      .optionallyWith(code.map(value => value.unwrap))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.FpgaImageState.ReadOnly =
    zio.aws.ec2.model.FpgaImageState.wrap(buildAwsValue())
}
object FpgaImageState {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.FpgaImageState
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.FpgaImageState = zio.aws.ec2.model
      .FpgaImageState(code.map(value => value), message.map(value => value))
    def code: Optional[zio.aws.ec2.model.FpgaImageStateCode]
    def message: Optional[String]
    def getCode: ZIO[Any, AwsError, zio.aws.ec2.model.FpgaImageStateCode] =
      AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.FpgaImageState
  ) extends zio.aws.ec2.model.FpgaImageState.ReadOnly {
    override val code: Optional[zio.aws.ec2.model.FpgaImageStateCode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.code())
        .map(value => zio.aws.ec2.model.FpgaImageStateCode.wrap(value))
    override val message: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.message())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.FpgaImageState
  ): zio.aws.ec2.model.FpgaImageState.ReadOnly = new Wrapper(impl)
}
